@@ -87,11 +87,11 @@ lg3 = matrix(new_c3, nrow = 3, ncol = 8, byrow = TRUE)
 test_that("relative entropy calc is correct on matrix", {
 
   # calculations are correct #1
-  expect_equal(get_boltzmann(lg, relative = TRUE, base = "log"), 81.745, tolerance = 1e-3)
-  expect_equal(get_boltzmann(lg, relative = TRUE, base = "log2"), 117.934, tolerance = 1e-3)
-  expect_equal(get_boltzmann(lg, relative = TRUE, base = "log10"), 35.501, tolerance = 1e-3)
+  expect_equal(get_boltzmann(lg, relative = TRUE, method = "hierarchy", base = "log"), 81.745, tolerance = 1e-3)
+  expect_equal(get_boltzmann(lg, relative = TRUE, method = "hierarchy", base = "log2"), 117.934, tolerance = 1e-3)
+  expect_equal(get_boltzmann(lg, relative = TRUE, method = "hierarchy", base = "log10"), 35.501, tolerance = 1e-3)
 
-  expect_equal(get_boltzmann(lg2, relative = TRUE, base = "log10"), 36.699, tolerance = 1e-3)
+  expect_equal(get_boltzmann(lg2, relative = TRUE, method = "hierarchy", base = "log10"), 36.699, tolerance = 1e-3)
 
   # warnings
 })
@@ -99,15 +99,15 @@ test_that("relative entropy calc is correct on matrix", {
 test_that("absolute entropy calc is correct on matrix", {
 
   # calculations are correct #1
-  expect_equal(get_boltzmann(lg, relative = FALSE, base = "log"), 111.519, tolerance = 1e-3)
-  expect_equal(get_boltzmann(lg, relative = FALSE, base = "log2"), 160.889, tolerance = 1e-3)
-  expect_equal(get_boltzmann(lg, relative = FALSE, base = "log10"), 48.432, tolerance = 1e-3)
+  expect_equal(get_boltzmann(lg, relative = FALSE, method = "hierarchy", base = "log"), 111.519, tolerance = 1e-3)
+  expect_equal(get_boltzmann(lg, relative = FALSE, method = "hierarchy", base = "log2"), 160.889, tolerance = 1e-3)
+  expect_equal(get_boltzmann(lg, relative = FALSE, method = "hierarchy", base = "log10"), 48.432, tolerance = 1e-3)
 
-  expect_equal(get_boltzmann(lg2, relative = FALSE, base = "log10"), 49.375, tolerance = 1e-3)
+  expect_equal(get_boltzmann(lg2, relative = FALSE, method = "hierarchy", base = "log10"), 49.375, tolerance = 1e-3)
 
 
   # calculations are correct #2
-  set_outputs = unlist(lapply(set_list, get_boltzmann, relative = FALSE))
+  set_outputs = unlist(lapply(set_list, get_boltzmann, relative = FALSE, method = "hierarchy"))
   expect_equal(set_results, set_outputs, tolerance = 1e-3)
 
   # bad inputs
@@ -117,7 +117,7 @@ test_that("absolute entropy calc is correct on matrix", {
 test_that("relative entropy calc is correct on array", {
 
   # calculations are correct #3
-  case_outputs = get_boltzmann(case_array, relative = TRUE)
+  case_outputs = get_boltzmann(case_array, relative = TRUE, method = "hierarchy")
   expect_equal(case_results, case_outputs, tolerance = 1e-3)
 
   # bad inputs
